@@ -577,7 +577,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
                 cartaporte_ubicaciones.appendChild(cartaporte_ubicacion)
             cartaporte.appendChild(cartaporte_ubicaciones)
             if self.tipo_transporte in ['AutotransporteFederal', 'TransporteFerroviario']:
-                cartaporte.setAttribute('TotalDistRec', str(total_distancia_recorrida))
+                cartaporte.setAttribute('TotalDistRec', str(round(total_distancia_recorrida, 3)))
 
             cartaporte_mercancias = self.dom.createElement('cartaporte20:Mercancias')
             mercancias = self.data.get('mercancias', [])
